"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Internal constants used for the AadTokenProvider
 * @internal
 */
var AadConstants = /** @class */ (function () {
    function AadConstants() {
    }
    /**
     * This string contains the resource used for the login reply URL. This resource
     * will wait until the id token has been retrieved.
     */
    AadConstants.SPFX_SINGLE_SIGN_ON_REPLY_URL = 'spfxsinglesignon.aspx';
    /**
     * This GUID is the unique identifier for SharePoint Online Web Client Extensibility Application Principal.
     * @remarks
     * For more information about Application and Service Principals, see
     * {@link https://docs.microsoft.com/en-us/azure/active-directory/develop/active-directory-application-objects}
     */
    AadConstants.PRE_AUTHORIZED_APP_PRINCIPAL_ID = '08e18876-6177-487e-b8b5-cf950c1e598c';
    /**
     * Set of error codes that cannot be resolved by user interation.
     * {@link https://docs.microsoft.com/en-us/azure/active-directory/develop/reference-aadsts-error-codes}
     */
    AadConstants.UNRESOLVABLE_AAD_ERROR_CODES = new Set([
        'AADSTS65001',
        'AADSTS53000',
        'AADSTS53003',
        'AADSTS500011',
        'AADSTS500341' // User Account deleted
    ]);
    /**
     * Set of error codes that can be resolved by a full page redirect to Azure AD.
     * {@link https://docs.microsoft.com/en-us/azure/active-directory/develop/reference-aadsts-error-codes}
     */
    AadConstants.RESOLVABLE_AAD_ERROR_CODES = new Set([
        'AADSTS50058',
        'AADSTS50076',
        'AADSTS50078',
        'AADSTS50079',
        'AADSTS50132',
        'AADSTS50133',
        'AADSTS50158',
        'AADSTS90033',
        'AADSTS160021' // Session does not exist
    ]);
    /**
     * Set of error codes that we mark as expected.
     * {@link https://docs.microsoft.com/en-us/azure/active-directory/develop/reference-aadsts-error-codes}
     */
    AadConstants.EXPECTED_AAD_ERRORS = new Set([
        'AADSTS53000',
        'AADSTS53003',
        'AADSTS50076',
        'AADSTS50079',
        'AADSTS50132',
        'AADSTS50133',
        'AADSTS50158',
        'AADSTS50173',
        'AADSTS500011',
        'AADSTS500341',
        'AADSTS700082',
        'AADSTS90033' // transient error
    ]);
    /**
     * Error code from AAD for login required.
     * {@link https://docs.microsoft.com/en-us/azure/active-directory/develop/reference-aadsts-error-codes}
     */
    AadConstants.LOGIN_REQUIRED = 'AADSTS50058';
    /**
     * Error code from AAD for timeout
     */
    AadConstants.TOKEN_RENEWAL_TIMEOUT = 'token_renewal_error';
    /**
     * Error code from AAD for network error
     */
    AadConstants.ENDPOINTS_RESOLUTION_ERROR = 'endpoints_resolution_error';
    /**
     * Error code from AAD for session does not exist error
     */
    AadConstants.SESSION_DOES_NOT_EXIST_ERROR = 'AADSTS160021';
    /**
     * Set of error codes that can be resolved by a full page redirect to Azure AD.
     * {@link https://docs.microsoft.com/en-us/azure/active-directory/develop/msal-handling-exceptions}
     */
    AadConstants.RESOLVABLE_ERROR_CODES = new Set([
        'interaction_required',
        'login_required'
    ]);
    /**
     * This string contains the ID of the Office 365 SharepointOnline AAD Application
     * , which is the same across all tenants
     */
    AadConstants.OFFICE_365_SHAREPOINT_ONLINE_ID = '00000003-0000-0ff1-ce00-000000000000';
    /**
     * This string contains the ID of the Microsoft Teams AAD Application
     * , which is the same across all tenants
     */
    AadConstants.MICROSOFT_TEAMS_ID = '1fec8e78-bce4-4aaf-ab1b-5451cc387264';
    /**
     * This string contains the link to SPO third party app Identifier Uri
     */
    AadConstants.SPO_THIRD_PARTY_APP_IDENTIFIER_URI = 'https://microsoft.spfx3rdparty.com';
    /**
     * This string contains the app id of the first party SP Framework AAD Helper
     */
    AadConstants.SPO_FIRST_PARTY_APP_HELPER_ID = 'e29b5c86-b9ab-4a86-9a20-d10842007599';
    return AadConstants;
}());
exports.default = AadConstants;
//# sourceMappingURL=AadConstants.js.map